# NotificationService.EmailApi

All URIs are relative to *http://zero-notification-service.notification-service/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**sendBulk**](EmailApi.md#sendBulk) | **POST** /email/sendBulk | Send a batch of multiple emails to individual recipients with the same content. Note that if cc or bcc address are provided, each email sent will also be sent to any addresses in these lists. Note that it is possible for only a subset of these to fail 
[**sendEmail**](EmailApi.md#sendEmail) | **POST** /email/send | Send a single email. Note that if multiple to addresses are provided it will still only send a single email with multiple addresses in the to field. To send multiple emails to individual addresses, see the sendBulk endpoint. 


# **sendBulk**
> SendBulkMailResponse sendBulk(sendBulkMailRequest)


### Example


```typescript
import { NotificationService } from '';
import * as fs from 'fs';

const configuration = NotificationService.createConfiguration();
const apiInstance = new NotificationService.EmailApi(configuration);

let body:NotificationService.EmailApiSendBulkRequest = {
  // SendBulkMailRequest | Parameters of the messages to send
  sendBulkMailRequest: {
    toAddresses: [
      {
        name: "name_example",
        address: "address_example",
      },
    ],
    ccAddresses: [
      {
        name: "name_example",
        address: "address_example",
      },
    ],
    bccAddresses: [
      {
        name: "name_example",
        address: "address_example",
      },
    ],
    fromAddress: {
      name: "name_example",
      address: "address_example",
    },
    message: {
      subject: "subject_example",
      body: "body_example",
      richBody: "richBody_example",
      templateId: "templateId_example",
      scheduleSendAtTimestamp: 1,
    },
    headers: {
      "key": "key_example",
    },
  },
};

apiInstance.sendBulk(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sendBulkMailRequest** | **SendBulkMailRequest**| Parameters of the messages to send |


### Return type

**SendBulkMailResponse**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**0** | unexpected error |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **sendEmail**
> SendMailResponse sendEmail(sendMailRequest)


### Example


```typescript
import { NotificationService } from '';
import * as fs from 'fs';

const configuration = NotificationService.createConfiguration();
const apiInstance = new NotificationService.EmailApi(configuration);

let body:NotificationService.EmailApiSendEmailRequest = {
  // SendMailRequest | Parameters of the message to send
  sendMailRequest: {
    toAddresses: [
      {
        name: "name_example",
        address: "address_example",
      },
    ],
    ccAddresses: [
      {
        name: "name_example",
        address: "address_example",
      },
    ],
    bccAddresses: [
      {
        name: "name_example",
        address: "address_example",
      },
    ],
    fromAddress: {
      name: "name_example",
      address: "address_example",
    },
    message: {
      subject: "subject_example",
      body: "body_example",
      richBody: "richBody_example",
      templateId: "templateId_example",
      scheduleSendAtTimestamp: 1,
    },
    headers: {
      "key": "key_example",
    },
    tags: [
      "tags_example",
    ],
    customArgs: {
      "key": "key_example",
    },
  },
};

apiInstance.sendEmail(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sendMailRequest** | **SendMailRequest**| Parameters of the message to send |


### Return type

**SendMailResponse**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**0** | unexpected error |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)


