"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ObservableSmsApi = exports.ObservableNotificationApi = exports.ObservableHealthApi = exports.ObservableEmailApi = void 0;
var rxjsStub_1 = require("../rxjsStub");
var rxjsStub_2 = require("../rxjsStub");
var EmailApi_1 = require("../apis/EmailApi");
var ObservableEmailApi = (function () {
    function ObservableEmailApi(configuration, requestFactory, responseProcessor) {
        this.configuration = configuration;
        this.requestFactory = requestFactory || new EmailApi_1.EmailApiRequestFactory(configuration);
        this.responseProcessor = responseProcessor || new EmailApi_1.EmailApiResponseProcessor();
    }
    ObservableEmailApi.prototype.sendBulkWithHttpInfo = function (sendBulkMailRequest, _options) {
        var _this = this;
        var requestContextPromise = this.requestFactory.sendBulk(sendBulkMailRequest, _options);
        var middlewarePreObservable = (0, rxjsStub_1.from)(requestContextPromise);
        var _loop_1 = function (middleware) {
            middlewarePreObservable = middlewarePreObservable.pipe((0, rxjsStub_2.mergeMap)(function (ctx) { return middleware.pre(ctx); }));
        };
        for (var _i = 0, _a = this.configuration.middleware; _i < _a.length; _i++) {
            var middleware = _a[_i];
            _loop_1(middleware);
        }
        return middlewarePreObservable.pipe((0, rxjsStub_2.mergeMap)(function (ctx) { return _this.configuration.httpApi.send(ctx); })).
            pipe((0, rxjsStub_2.mergeMap)(function (response) {
            var middlewarePostObservable = (0, rxjsStub_1.of)(response);
            var _loop_2 = function (middleware) {
                middlewarePostObservable = middlewarePostObservable.pipe((0, rxjsStub_2.mergeMap)(function (rsp) { return middleware.post(rsp); }));
            };
            for (var _i = 0, _a = _this.configuration.middleware; _i < _a.length; _i++) {
                var middleware = _a[_i];
                _loop_2(middleware);
            }
            return middlewarePostObservable.pipe((0, rxjsStub_2.map)(function (rsp) { return _this.responseProcessor.sendBulkWithHttpInfo(rsp); }));
        }));
    };
    ObservableEmailApi.prototype.sendBulk = function (sendBulkMailRequest, _options) {
        return this.sendBulkWithHttpInfo(sendBulkMailRequest, _options).pipe((0, rxjsStub_2.map)(function (apiResponse) { return apiResponse.data; }));
    };
    ObservableEmailApi.prototype.sendEmailWithHttpInfo = function (sendMailRequest, _options) {
        var _this = this;
        var requestContextPromise = this.requestFactory.sendEmail(sendMailRequest, _options);
        var middlewarePreObservable = (0, rxjsStub_1.from)(requestContextPromise);
        var _loop_3 = function (middleware) {
            middlewarePreObservable = middlewarePreObservable.pipe((0, rxjsStub_2.mergeMap)(function (ctx) { return middleware.pre(ctx); }));
        };
        for (var _i = 0, _a = this.configuration.middleware; _i < _a.length; _i++) {
            var middleware = _a[_i];
            _loop_3(middleware);
        }
        return middlewarePreObservable.pipe((0, rxjsStub_2.mergeMap)(function (ctx) { return _this.configuration.httpApi.send(ctx); })).
            pipe((0, rxjsStub_2.mergeMap)(function (response) {
            var middlewarePostObservable = (0, rxjsStub_1.of)(response);
            var _loop_4 = function (middleware) {
                middlewarePostObservable = middlewarePostObservable.pipe((0, rxjsStub_2.mergeMap)(function (rsp) { return middleware.post(rsp); }));
            };
            for (var _i = 0, _a = _this.configuration.middleware; _i < _a.length; _i++) {
                var middleware = _a[_i];
                _loop_4(middleware);
            }
            return middlewarePostObservable.pipe((0, rxjsStub_2.map)(function (rsp) { return _this.responseProcessor.sendEmailWithHttpInfo(rsp); }));
        }));
    };
    ObservableEmailApi.prototype.sendEmail = function (sendMailRequest, _options) {
        return this.sendEmailWithHttpInfo(sendMailRequest, _options).pipe((0, rxjsStub_2.map)(function (apiResponse) { return apiResponse.data; }));
    };
    return ObservableEmailApi;
}());
exports.ObservableEmailApi = ObservableEmailApi;
var HealthApi_1 = require("../apis/HealthApi");
var ObservableHealthApi = (function () {
    function ObservableHealthApi(configuration, requestFactory, responseProcessor) {
        this.configuration = configuration;
        this.requestFactory = requestFactory || new HealthApi_1.HealthApiRequestFactory(configuration);
        this.responseProcessor = responseProcessor || new HealthApi_1.HealthApiResponseProcessor();
    }
    ObservableHealthApi.prototype.readyCheckWithHttpInfo = function (_options) {
        var _this = this;
        var requestContextPromise = this.requestFactory.readyCheck(_options);
        var middlewarePreObservable = (0, rxjsStub_1.from)(requestContextPromise);
        var _loop_5 = function (middleware) {
            middlewarePreObservable = middlewarePreObservable.pipe((0, rxjsStub_2.mergeMap)(function (ctx) { return middleware.pre(ctx); }));
        };
        for (var _i = 0, _a = this.configuration.middleware; _i < _a.length; _i++) {
            var middleware = _a[_i];
            _loop_5(middleware);
        }
        return middlewarePreObservable.pipe((0, rxjsStub_2.mergeMap)(function (ctx) { return _this.configuration.httpApi.send(ctx); })).
            pipe((0, rxjsStub_2.mergeMap)(function (response) {
            var middlewarePostObservable = (0, rxjsStub_1.of)(response);
            var _loop_6 = function (middleware) {
                middlewarePostObservable = middlewarePostObservable.pipe((0, rxjsStub_2.mergeMap)(function (rsp) { return middleware.post(rsp); }));
            };
            for (var _i = 0, _a = _this.configuration.middleware; _i < _a.length; _i++) {
                var middleware = _a[_i];
                _loop_6(middleware);
            }
            return middlewarePostObservable.pipe((0, rxjsStub_2.map)(function (rsp) { return _this.responseProcessor.readyCheckWithHttpInfo(rsp); }));
        }));
    };
    ObservableHealthApi.prototype.readyCheck = function (_options) {
        return this.readyCheckWithHttpInfo(_options).pipe((0, rxjsStub_2.map)(function (apiResponse) { return apiResponse.data; }));
    };
    return ObservableHealthApi;
}());
exports.ObservableHealthApi = ObservableHealthApi;
var NotificationApi_1 = require("../apis/NotificationApi");
var ObservableNotificationApi = (function () {
    function ObservableNotificationApi(configuration, requestFactory, responseProcessor) {
        this.configuration = configuration;
        this.requestFactory = requestFactory || new NotificationApi_1.NotificationApiRequestFactory(configuration);
        this.responseProcessor = responseProcessor || new NotificationApi_1.NotificationApiResponseProcessor();
    }
    ObservableNotificationApi.prototype.sendSlackNotificationWithHttpInfo = function (sendSlackMessageRequest, _options) {
        var _this = this;
        var requestContextPromise = this.requestFactory.sendSlackNotification(sendSlackMessageRequest, _options);
        var middlewarePreObservable = (0, rxjsStub_1.from)(requestContextPromise);
        var _loop_7 = function (middleware) {
            middlewarePreObservable = middlewarePreObservable.pipe((0, rxjsStub_2.mergeMap)(function (ctx) { return middleware.pre(ctx); }));
        };
        for (var _i = 0, _a = this.configuration.middleware; _i < _a.length; _i++) {
            var middleware = _a[_i];
            _loop_7(middleware);
        }
        return middlewarePreObservable.pipe((0, rxjsStub_2.mergeMap)(function (ctx) { return _this.configuration.httpApi.send(ctx); })).
            pipe((0, rxjsStub_2.mergeMap)(function (response) {
            var middlewarePostObservable = (0, rxjsStub_1.of)(response);
            var _loop_8 = function (middleware) {
                middlewarePostObservable = middlewarePostObservable.pipe((0, rxjsStub_2.mergeMap)(function (rsp) { return middleware.post(rsp); }));
            };
            for (var _i = 0, _a = _this.configuration.middleware; _i < _a.length; _i++) {
                var middleware = _a[_i];
                _loop_8(middleware);
            }
            return middlewarePostObservable.pipe((0, rxjsStub_2.map)(function (rsp) { return _this.responseProcessor.sendSlackNotificationWithHttpInfo(rsp); }));
        }));
    };
    ObservableNotificationApi.prototype.sendSlackNotification = function (sendSlackMessageRequest, _options) {
        return this.sendSlackNotificationWithHttpInfo(sendSlackMessageRequest, _options).pipe((0, rxjsStub_2.map)(function (apiResponse) { return apiResponse.data; }));
    };
    return ObservableNotificationApi;
}());
exports.ObservableNotificationApi = ObservableNotificationApi;
var SmsApi_1 = require("../apis/SmsApi");
var ObservableSmsApi = (function () {
    function ObservableSmsApi(configuration, requestFactory, responseProcessor) {
        this.configuration = configuration;
        this.requestFactory = requestFactory || new SmsApi_1.SmsApiRequestFactory(configuration);
        this.responseProcessor = responseProcessor || new SmsApi_1.SmsApiResponseProcessor();
    }
    ObservableSmsApi.prototype.sendSMSWithHttpInfo = function (sendSMSRequest, _options) {
        var _this = this;
        var requestContextPromise = this.requestFactory.sendSMS(sendSMSRequest, _options);
        var middlewarePreObservable = (0, rxjsStub_1.from)(requestContextPromise);
        var _loop_9 = function (middleware) {
            middlewarePreObservable = middlewarePreObservable.pipe((0, rxjsStub_2.mergeMap)(function (ctx) { return middleware.pre(ctx); }));
        };
        for (var _i = 0, _a = this.configuration.middleware; _i < _a.length; _i++) {
            var middleware = _a[_i];
            _loop_9(middleware);
        }
        return middlewarePreObservable.pipe((0, rxjsStub_2.mergeMap)(function (ctx) { return _this.configuration.httpApi.send(ctx); })).
            pipe((0, rxjsStub_2.mergeMap)(function (response) {
            var middlewarePostObservable = (0, rxjsStub_1.of)(response);
            var _loop_10 = function (middleware) {
                middlewarePostObservable = middlewarePostObservable.pipe((0, rxjsStub_2.mergeMap)(function (rsp) { return middleware.post(rsp); }));
            };
            for (var _i = 0, _a = _this.configuration.middleware; _i < _a.length; _i++) {
                var middleware = _a[_i];
                _loop_10(middleware);
            }
            return middlewarePostObservable.pipe((0, rxjsStub_2.map)(function (rsp) { return _this.responseProcessor.sendSMSWithHttpInfo(rsp); }));
        }));
    };
    ObservableSmsApi.prototype.sendSMS = function (sendSMSRequest, _options) {
        return this.sendSMSWithHttpInfo(sendSMSRequest, _options).pipe((0, rxjsStub_2.map)(function (apiResponse) { return apiResponse.data; }));
    };
    return ObservableSmsApi;
}());
exports.ObservableSmsApi = ObservableSmsApi;
//# sourceMappingURL=ObservableAPI.js.map